pub enum MigrationState {
NotStarted,
StartedExport {
next_begin_used: u32,
},
CompletedExport,
StartedOverweightExport {
next_overweight_index: u64,
},
CompletedOverweightExport,
StartedCleanup {
cursor: Option<BoundedVec<u8, ConstU32<1024>>>,
},
Completed,
}๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.Expand description
The lazy-migration state of the pallet.
Variants
NotStarted
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.Migration has not started yet.
StartedExport
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The export of pages started.
Fields

next_begin_used: u32๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The next page that should be exported.
CompletedExport
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The page export completed.
StartedOverweightExport
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The export of overweight messages started.
Fields

next_overweight_index: u64๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The next overweight index that should be exported.
CompletedOverweightExport
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The export of overweight messages completed.
StartedCleanup
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The storage cleanup started.
Fields

cursor: Option<BoundedVec<u8, ConstU32<1024>>>๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.Completed
๐Deprecated:
cumulus-pallet-dmp-queue will be removed after November 2024. It can be removed once its lazy migration completed. See https://github.com/paritytech/polkadot-sdk/pull/1246.The migration finished. The pallet can now be removed from the runtime.